@@ -26,21 +26,24 @@
 //! #[test]
 //! fn cli_tests() {
 //!     trycmd::TestCases::new()
-//!         .case("tests/cmd/*.trycmd");
+//!         .case("tests/cmd/*.toml")
+//!         .case("README.md");
 //! }
 //! ```
+//! and write out your test cases in your `.toml` files along with examples in your `README.md`.
 //!
-//! The test can be run with `cargo test`.  This will enumerate all `.trycmd` files and run
-//! them as test cases, failing if they do not pass.
+//! Run this with `cargo test` like normal.  [`TestCases`] will enumerate all test case files and
+//! run the contained commands, verifying they run as expected.
 //!
 //! To temporarily override the results, you can do:
 //! ```rust,no_run
 //! #[test]
 //! fn cli_tests() {
 //!     trycmd::TestCases::new()
-//!         .case("tests/cmd/*.trycmd")
+//!         .case("tests/cmd/*.toml")
+//!         .case("README.md")
 //!         // See Issue #314
-//!         .fail("tests/cmd/buggy-case.trycmd");
+//!         .fail("tests/cmd/buggy-case.toml");
 //! }
 //! ```
 //!
@@ -65,15 +68,15 @@
 //! cargo test --test cli_tests -- cli_tests trycmd=name1 trycmd=name2...
 //! ```
 //!
-//! To debug what `trycmd` is doing, add the feature flag `debug`.
+//! To debug what `trycmd` is doing, run `cargo test -F trycmd/debug`.
 //!
 //! ## File Formats
 //!
-//! Say you have `tests/cmd/help.trycmd`, `trycmd` will look for:
+//! For `tests/cmd/help.trycmd`, `trycmd` will look for:
 //! - `tests/cmd/help.in/`
 //! - `tests/cmd/help.out/`
 //!
-//! For `tests/cmd/help.toml`, `trycmd` will look for:
+//! Say you have `tests/cmd/help.toml`, `trycmd` will look for:
 //! - `tests/cmd/help.stdin`
 //! - `tests/cmd/help.stdout`
 //! - `tests/cmd/help.stderr`
@@ -82,11 +85,11 @@
 //!
 //! ### `*.trycmd`
 //!
-//! `*.trycmd` files are literate test cases good for:
+//! `*.trycmd` / `*.md` files are literate test cases good for:
 //! - Markdown-compatible syntax for directly rendering them
 //! - Terminal-like appearance for extracting subsections into documentation
 //! - Reducing the proliferation of files
-//! - Running multiple commands within the same temp dir
+//! - Running multiple commands within the same temp dir (if a `*.out/` directory is present)
 //!
 //! The syntax is:
 //! - Test cases live inside of ` ``` ` fenced code blocks
@@ -105,19 +108,26 @@
 //! `.toml` file.
 //!
 //! Example:
-//! ~~~md
-//! With the following code:
-//! ```rust
-//! println!("{}", message);
+//!
+//! With a `[[bin]]` like:
+//! ```rust,ignore
+//! fn main() {
+//!     println!("Hello world");
+//! }
 //! ```
 //!
-//! You get the following:
-//! ```
-//! $ my-cmd --print 'Hello World'
-//! Hello
+//! You can verify a code block like:
+//! ~~~md
+//! ```console
+//! $ my-cmd
+//! Hello world
+//!
 //! ```
 //! ~~~
 //!
+//! For a more complete example, see:
+//! <https://github.com/assert-rs/trycmd/tree/main/examples/demo_trycmd>.
+//!
 //! ### `*.toml`
 //!
 //! As an alternative to `.trycmd`, the `toml` are good for:
@@ -125,8 +135,10 @@
 //! - 1-to-1 with dumped results
 //! - `TRYCMD=overwrite` support
 //!
-//! [schema](https://github.com/assert-rs/trycmd/blob/main/schema.json):
+//! [See full schema](https://github.com/assert-rs/trycmd/blob/main/schema.json):
+//! Basic parameters:
 //! - `bin.name`: The name of the binary target from `Cargo.toml` to be used to find the file path
+//! - `args`: the arguments (including flags and option) passed to the binary
 //!
 //! #### `*.stdin`
 //!
@@ -164,6 +176,9 @@
 //!
 //! `.keep` files will be ignored but their parent directories will be created.
 //!
+//! Tests are assumed to not modify files in `*.in/` unless an `*.out/` is provided or
+//! `fs.sandbox = true` is set in the `.toml` file.
+//!
 //! ### `*.out/`
 //!
 //! When present, each file in this directory will be compared to generated or modified files.
@@ -172,6 +187,8 @@
 //!
 //! `.keep` files will be ignored.
 //!
+//! Note: This implies `fs.sandbox = true`.
+//!
 //! ## Examples
 //!
 //! - Simple cargo binary: [trycmd's integration tests](https://github.com/assert-rs/trycmd/blob/main/tests/cli_tests.rs)
@@ -211,6 +228,8 @@
 #![cfg_attr(docsrs, feature(doc_auto_cfg))]
 // Doesn't distinguish between incidental sharing vs essential sharing
 #![allow(clippy::branches_sharing_code)]
+// Forces indentation that may not represent the logic
+#![allow(clippy::collapsible_else_if)]
 
 pub mod cargo;
 pub mod schema;
