@@ -1,7 +1,19 @@
 use std::io::prelude::*;
 
+#[cfg(feature = "color")]
+use anstream::eprintln;
+#[cfg(feature = "color")]
+use anstream::panic;
+#[cfg(feature = "color")]
+use anstream::stderr;
+#[cfg(not(feature = "color"))]
+use std::eprintln;
+#[cfg(not(feature = "color"))]
+use std::io::stderr;
+
 use rayon::prelude::*;
 use snapbox::path::FileType;
+use snapbox::{DataFormat, NormalizeNewlines, NormalizePaths};
 
 #[derive(Debug)]
 pub(crate) struct Runner {
@@ -25,7 +37,7 @@ impl Runner {
         bins: &crate::BinRegistry,
         substitutions: &snapbox::Substitutions,
     ) {
-        let palette = snapbox::report::Palette::auto();
+        let palette = snapbox::report::Palette::color();
 
         if self.cases.is_empty() {
             eprintln!("{}", palette.warn("There are no trycmd tests enabled yet"));
@@ -36,7 +48,7 @@ impl Runner {
                 .flat_map(|c| {
                     let results = c.run(mode, bins, substitutions);
 
-                    let stderr = std::io::stderr();
+                    let stderr = stderr();
                     let mut stderr = stderr.lock();
 
                     results
@@ -77,7 +89,7 @@ impl Runner {
                 .collect();
 
             if !failures.is_empty() {
-                let stderr = std::io::stderr();
+                let stderr = stderr();
                 let mut stderr = stderr.lock();
                 let _ = writeln!(
                     stderr,
@@ -235,14 +247,19 @@ impl Case {
             }
             Mode::Overwrite => {
                 // `rev()` to ensure we don't mess up our line number info
-                for output in outputs.iter().rev() {
-                    if let Err(output) = output {
-                        let _ = sequence.overwrite(
+                for step_status in outputs.iter_mut().rev() {
+                    if let Err(output) = step_status {
+                        let res = sequence.overwrite(
                             &self.path,
                             output.id.as_deref(),
                             output.stdout.as_ref().map(|s| &s.content),
                             output.stderr.as_ref().map(|s| &s.content),
+                            output.spawn.exit,
                         );
+
+                        if res.is_ok() {
+                            *step_status = Ok(output.clone());
+                        }
                     }
                 }
             }
@@ -320,18 +337,22 @@ impl Case {
             return Ok(output);
         }
 
-        #[allow(unused_variables)]
         match &step.bin {
             Some(crate::schema::Bin::Path(_)) => {}
-            Some(crate::schema::Bin::Name(name)) => {
+            Some(crate::schema::Bin::Name(_name)) => {
                 // Unhandled by resolve
-                snapbox::debug!("bin={:?} not found", name);
+                snapbox::debug!("bin={:?} not found", _name);
                 assert_eq!(output.spawn.status, SpawnStatus::Skipped);
                 return Ok(output);
             }
             Some(crate::schema::Bin::Error(_)) => {}
             // Unlike `Name`, this always represents a bug
             None => {}
+            Some(crate::schema::Bin::Ignore) => {
+                // Unhandled by resolve
+                assert_eq!(output.spawn.status, SpawnStatus::Skipped);
+                return Ok(output);
+            }
         }
 
         let cmd = step.to_command(cwd).map_err(|e| output.clone().error(e))?;
@@ -419,9 +440,11 @@ impl Case {
         }
 
         if let Some(expected_content) = expected_content {
-            if let Some(e) = expected_content.as_str() {
-                stream.content = stream.content.map_text(|t| substitutions.normalize(t, e));
-            }
+            stream.content = stream.content.normalize(snapbox::NormalizeMatches::new(
+                substitutions,
+                expected_content,
+            ));
+
             if stream.content != *expected_content {
                 stream.status = StreamStatus::Expected(expected_content.clone());
                 return Some(stream);
@@ -630,7 +653,7 @@ impl Default for Spawn {
 
 impl std::fmt::Display for Spawn {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        let palette = snapbox::report::Palette::auto();
+        let palette = snapbox::report::Palette::color();
 
         match &self.status {
             SpawnStatus::Ok => {
@@ -659,19 +682,12 @@ impl std::fmt::Display for Spawn {
                             palette.info(expected),
                             palette.error("success")
                         )?;
-                    } else if let Some(code) = exit.code() {
-                        writeln!(
-                            f,
-                            "Expected {}, was {}",
-                            palette.info(expected),
-                            palette.error(code)
-                        )?;
                     } else {
                         writeln!(
                             f,
                             "Expected {}, was {}",
                             palette.info(expected),
-                            palette.error("interrupted")
+                            palette.error(snapbox::cmd::display_exit_status(exit))
                         )?;
                     }
                 }
@@ -699,7 +715,7 @@ impl SpawnStatus {
     }
 
     fn summary(&self) -> impl std::fmt::Display {
-        let palette = snapbox::report::Palette::auto();
+        let palette = snapbox::report::Palette::color();
         match self {
             Self::Ok => palette.info("ok"),
             Self::Skipped => palette.warn("ignored"),
@@ -717,10 +733,13 @@ struct Stream {
 
 impl Stream {
     fn make_text(mut self) -> Self {
-        if self.content.make_text().is_err() {
-            self.status = StreamStatus::Failure("invalid UTF-8".into());
+        let content = self.content.try_coerce(DataFormat::Text);
+        if content.format() != DataFormat::Text {
+            self.status = StreamStatus::Failure("Unable to convert underlying Data to Text".into());
         }
-        self.content = self.content.map_text(snapbox::utils::normalize_text);
+        self.content = content
+            .normalize(NormalizePaths)
+            .normalize(NormalizeNewlines);
         self
     }
 
@@ -731,7 +750,7 @@ impl Stream {
 
 impl std::fmt::Display for Stream {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        let palette = snapbox::report::Palette::auto();
+        let palette = snapbox::report::Palette::color();
 
         match &self.status {
             StreamStatus::Ok => {
@@ -907,7 +926,7 @@ impl From<snapbox::path::PathDiff> for FileStatus {
 
 impl std::fmt::Display for FileStatus {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        let palette = snapbox::report::Palette::auto();
+        let palette = snapbox::report::Palette::color();
 
         match &self {
             Self::Ok {
